# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.authorization_v1_api import AuthorizationV1Api


class TestAuthorizationV1Api(unittest.TestCase):
    """AuthorizationV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthorizationV1Api()

    def tearDown(self) -> None:
        pass

    def test_check_permissions(self) -> None:
        """Test case for check_permissions

        Check Permissions
        """
        pass

    def test_delete_role_binding(self) -> None:
        """Test case for delete_role_binding

        Delete Role Binding.
        """
        pass

    def test_list_group_role_bindings(self) -> None:
        """Test case for list_group_role_bindings

        Get Group Role Bindings.
        """
        pass

    def test_list_org_role_bindings(self) -> None:
        """Test case for list_org_role_bindings

        List Organization Role Bindings.
        """
        pass

    def test_list_permissions_library(self) -> None:
        """Test case for list_permissions_library

        List Permissions
        """
        pass

    def test_list_project_role_bindings(self) -> None:
        """Test case for list_project_role_bindings

        List Project Role Bindings.
        """
        pass

    def test_list_roles(self) -> None:
        """Test case for list_roles

        List Roles
        """
        pass

    def test_list_user_role_bindings(self) -> None:
        """Test case for list_user_role_bindings

        Get User Role Bindings.
        """
        pass

    def test_list_workspace_role_bindings(self) -> None:
        """Test case for list_workspace_role_bindings

        List Workspace Role Bindings.
        """
        pass

    def test_post_org_role_binding(self) -> None:
        """Test case for post_org_role_binding

        Post Organization Role Binding.
        """
        pass

    def test_post_project_role_binding(self) -> None:
        """Test case for post_project_role_binding

        Post Project Role Binding
        """
        pass

    def test_post_workspace_role_binding(self) -> None:
        """Test case for post_workspace_role_binding

        Post Workspace Role Binding.
        """
        pass


if __name__ == '__main__':
    unittest.main()
